@@ -19,14 +19,10 @@
 
 """Sensors plugin."""
 
-# Sensors library (optional; Linux-only)
-# Py3Sensors: https://bitbucket.org/gleb_zhulik/py3sensors
-try:
-    import sensors
-except ImportError:
-    pass
+import psutil
 
 from glances.logger import logger
+from glances.compat import iteritems
 from glances.plugins.glances_batpercent import Plugin as BatPercentPlugin
 from glances.plugins.glances_hddtemp import Plugin as HddTempPlugin
 from glances.plugins.glances_plugin import GlancesPlugin
@@ -223,17 +219,29 @@ class Plugin(GlancesPlugin):
 
 class GlancesGrabSensors(object):
 
-    """Get sensors stats using the py3sensors library."""
+    """Get sensors stats."""
 
     def __init__(self):
         """Init sensors stats."""
+        # Temperatures
         try:
-            sensors.init()
-        except Exception:
+            # psutil>=5.1.0 is required
+            self.stemps = psutil.sensors_temperatures()
+        except AttributeError:
+            logger.warning("PsUtil 5.1.0 or higher is needed to grab temperatures sensors")
             self.initok = False
+            self.stemps = {}
         else:
             self.initok = True
 
+        # Fans
+        try:
+            # psutil>=5.2.0 is required
+            self.sfans = psutil.sensors_fans()
+        except AttributeError:
+            logger.warning("PsUtil 5.2.0 or higher is needed to grab fans sensors")
+            self.sfans = {}
+
         # Init the stats
         self.reset()
 
@@ -246,27 +254,47 @@ class GlancesGrabSensors(object):
         # Reset the list
         self.reset()
 
-        if self.initok:
-            for chip in sensors.iter_detected_chips():
-                for feature in chip:
-                    sensors_current = {}
-                    if feature.name.startswith(b'temp'):
-                        # Temperature sensor
-                        sensors_current['unit'] = SENSOR_TEMP_UNIT
-                    elif feature.name.startswith(b'fan'):
-                        # Fan speed sensor
-                        sensors_current['unit'] = SENSOR_FAN_UNIT
-                    if sensors_current:
-                        try:
-                            sensors_current['label'] = feature.label
-                            sensors_current['value'] = int(feature.get_value())
-                        except Exception as e:
-                            logger.debug("Cannot grab sensor stat (%s)" % e)
-                        else:
-                            self.sensors_list.append(sensors_current)
+        if not self.initok:
+            return self.sensors_list
+
+        # Temperatures sensors
+        self.sensors_list.extend(self.build_sensors_list(SENSOR_TEMP_UNIT))
+
+        # Fans sensors
+        self.sensors_list.extend(self.build_sensors_list(SENSOR_FAN_UNIT))
 
         return self.sensors_list
 
+    def build_sensors_list(self, type):
+        """Build the sensors list depending of the type.
+
+        type: SENSOR_TEMP_UNIT or SENSOR_FAN_UNIT
+
+        output: a list"""
+        ret = []
+        if type == SENSOR_TEMP_UNIT:
+            input_list = self.stemps
+        elif type == SENSOR_FAN_UNIT:
+            input_list = self.sfans
+        else:
+            return ret
+        for chipname, chip in iteritems(input_list):
+            i = 1
+            for feature in chip:
+                sensors_current = {}
+                # Sensor name
+                if feature.label == '':
+                    sensors_current['label'] = chipname + ' ' + str(i)
+                else:
+                    sensors_current['label'] = feature.label
+                # Fan speed and unit
+                sensors_current['value'] = int(feature.current)
+                sensors_current['unit'] = type
+                # Add sensor to the list
+                ret.append(sensors_current)
+                i += 1
+        return ret
+
     def get(self, sensor_type='temperature_core'):
         """Get sensors list."""
         self.__update__()
