@@ -29,12 +29,6 @@ from glances.logger import logger
 
 import psutil
 
-# Workaround for old PsUtil version
-if hasattr(psutil, 'WindowsError'):
-    PsUtilWindowsError = psutil.WindowsError
-else:
-    PsUtilWindowsError = None
-
 
 def is_kernel_thread(proc):
     """Return True if proc is a kernel thread, False instead."""
@@ -275,7 +269,8 @@ class GlancesProcesses(object):
             # Patch for issue #391
             try:
                 self.cmdline_cache[procstat['pid']] = proc.cmdline()
-            except (AttributeError, UnicodeDecodeError, psutil.AccessDenied, psutil.NoSuchProcess, PsUtilWindowsError):
+            except (AttributeError, EnvironmentError, UnicodeDecodeError,
+                    psutil.AccessDenied, psutil.NoSuchProcess):
                 self.cmdline_cache[procstat['pid']] = ""
         procstat['cmdline'] = self.cmdline_cache[procstat['pid']]
 
